Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/srunx/callbacks.py | 29 | 4 | 0 | 86%
src/srunx/cli/main.py | 314 | 132 | 2 | 58%
src/srunx/cli/workflow.py | 50 | 50 | 2 | 0%
src/srunx/client.py | 153 | 20 | 0 | 87%
src/srunx/config.py | 133 | 20 | 0 | 85%
src/srunx/exceptions.py | 3 | 0 | 0 | 100%
src/srunx/logging.py | 26 | 17 | 0 | 35%
src/srunx/models.py | 233 | 41 | 0 | 82%
src/srunx/runner.py | 141 | 6 | 0 | 96%
src/srunx/utils.py | 31 | 0 | 0 | 100%
Total | 1113 | 290 | 4 | 74%

No items found using the specified filter.